# coding: utf-8
from spyne.model.complex import Array, ComplexModel
from spyne.model.primitive import Integer, String, Unicode

from .utils import create_attachment


class Item(ComplexModel):

    __type_name__ = 'item'

    count = Integer  # Кол-во входов за период

    teacher_id = Integer
    fullname = Unicode

    date = String
    times = String

    control_unit = Unicode
    control_unit_id = Integer

    school_id = Integer
    school_shortname = Unicode
    school_name = Unicode

    class Annotations(ComplexModel.Annotations):

        doc = u'Контейнер, содержащий данные сотрудника.'


class Root(ComplexModel):

    __type_name__ = 'root'

    employees = Array(Item)

    class Annotations(ComplexModel.Annotations):

        doc = u'Контейнер, содержащий список сотрудников.'


class GetIndexResponse(ComplexModel):

    __type_name__ = 'GetIndexResponse'

    _type_info = [
        ('IndexFilename', String),
        ('IndexBinaryData', Unicode),
    ]

    @classmethod
    def create(cls, file_name, content):
        content = create_attachment(file_name, content)
        return cls(
            IndexFilename=file_name, IndexBinaryData=content
        )

    class Annotations(ComplexModel.Annotations):

        doc = u'Ответ на запрос GetIndexRequest'


class IndexPeriod(ComplexModel):

    IndexPeriodType = Unicode(max_occurs=1)
    IndexPeriodDate = Unicode(max_occurs=1)
    IndexPeriodStartDate = Unicode(max_occurs=1)
    IndexPeriodEndDate = Unicode(max_occurs=1)

    class Annotations(ComplexModel.Annotations):

        doc = u'Данные периода выборки.'
